autosubmit.config
=================

autosubmitconfigparser.config.basicConfig
-----------------------------------------

.. automodule:: autosubmitconfigparser.config.basicconfig
   :show-inheritance:
   :inherited-members:
   :members:

autosubmitconfigparser.config.config_common
-------------------------------------------
.. automodule:: autosubmitconfigparser.config.configcommon
   :show-inheritance:
   :inherited-members:
   :members:

